@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from typing import TypeVar
+from typing import TypeVar, Literal
 from functools import reduce
 from operator import getitem
 
@@ -11,32 +11,19 @@ _T = TypeVar('_T')
 
 
 class ObjectUtil(object):
-
-    class MagicClass(object):
-        _str_exclude = {}
-        _repr_exclude = {}
-        _call_exclude = {}
-        _str_include = {}
-        _repr_include = {}
-        _call_include = {}
-
-
-        def __str__(self) -> str:
-            return ObjectUtil.repr(self, self._str_exclude, self._str_include)
-
-        def __repr__(self) -> str:
-            return ObjectUtil.repr(self, self._repr_exclude, self._repr_include)
-
-        def __call__(self) -> dict:
-            return ObjectUtil.vars(self, self._call_exclude, self._call_include)
+    """对象工具类"""
 
     @staticmethod
     def repr(obj: object, exclude: set[str] = {}, include: set[str] = {}) -> str:
         """将对象转为描述属性的字符串
-        :param obj 对象
-        :param exclude (可选) 忽略属性列表
-        :param include (可选) 包含属性列表
-        :return 对象详情字符串
+
+        Args:
+            obj (object): _description_
+            exclude (set[str], optional): 忽略属性列表. 默认为 {}.
+            include (set[str], optional): 包含属性列表. 默认为 {}.
+
+        Returns:
+            str: 对象详情字符串
         """
         class_name = obj.__class__.__name__
         attributes = [
@@ -52,11 +39,15 @@ class ObjectUtil(object):
     @staticmethod
     def vars(obj: object, exclude: set[str] = {}, include: set[str] = {}, style='snake') -> dict:
         """将对象的属性转为字典形式
-        :param obj 对象
-        :param exclude (可选) 忽略属性列表
-        :param include (可选) 包含属性列表
-        :param style (可选 'camel',  默认 'snake') 键名命名风格，为 None 不转换
-        :return 对象 { 属性: 值 } 组成的字典
+
+        Args:
+            obj (object): 对象实例
+            exclude (set[str], optional): 忽略属性列表. 默认为 {}.
+            include (set[str], optional): 包含属性列表. 默认为 {}.
+            style (str, optional): 键名命名风格，为 None 不转换. 默认为 'snake'.
+
+        Returns:
+            dict: 对象 { 属性: 值 } 组成的字典
         """
         dict_items = {}
         if isinstance(obj, dict):
@@ -89,13 +80,17 @@ class ObjectUtil(object):
         }
 
     @staticmethod
-    def update_with_dict(obj: _T, **kw) -> _T:
+    def update_with_dict(obj: _T, *, exclude: set[str] = {}, style: Literal['snake', 'camel'] = 'snake', **kw) -> _T:
         """用关键字参数将对象赋值, 并忽略对象上不存在的属性
-        :param obj 对象
-        :param **kw 关键字参数
-        :param exclude (可选) 忽略属性列表
-        :param style (可选 'camel',  默认 'snake') 键名命名风格
-        :return 更新数据后的对象
+
+        Args:
+            obj (_T): 对象实例
+            exclude (set[str], optional): 忽略属性列表. 默认为 {}.
+            style (Literal[&#39;snake&#39;, &#39;camel&#39;], optional): 键名命名风格. 默认为 'snake'.
+            **kw: 关键字参数
+
+        Returns:
+            _T: 更新数据后的对象实例
         """
         style = kw.get('style', 'snake')
         exclude = kw.get('exclude', [])
@@ -111,9 +106,14 @@ class ObjectUtil(object):
     @staticmethod
     def get_value_from_dict(data_dict: dict, key_string: str, default = None) -> any:
         """根据带点字符串的层级取出字典中的数据
-        :param data_dict 类字典类型
-        :param key_string 以英文句号分隔的字符串
-        :param default 默认值
+
+        Args:
+            data_dict (dict): 类字典类型
+            key_string (str): 以英文句号分隔的字符串
+            default (_type_, optional): 默认值. 默认为 None.
+
+        Returns:
+            any: 字典中对应的值
         """
         keys = key_string.split('.')
         try:
